==> 7.1.16.5-TIV-PROSPECTDA-NORCDM-FP0000.tar: patches/7.1.16.5-TIV-PROSPECTDA-NORCDM-FP0000/extract_rmt.pl <==
#!/usr/bin/perl

##########################################################################
#
# Licensed Materials - Property of IBM
# 5724-T10
#
# (C) Copyright IBM Corp. 2003,2008. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
##########################################################################

#! Anthony Jesu - 2006/05/02
#
# 1) This script parses the data from input file for the specified
#    time_stamp.for Example if the input time is 200507030200 then
#    and the arguement also passed 'start' then this program fetches
#    30 minutes interval of in forward manner. for example this will
#    fetch data from 2'O clock to 02:29 minutes of data. Instead of start
#    If you pass end, then this script fetches the information in reverse order.
#    In our case this will fetch information in the previous interval (i,e) from
#    01.30 to 01.59 of data.
# 2) Output filename is same as input filename with ".extract" appended.

use lib "$ENV{ FLEXDAHOME }/scripts/";
use Tool;

if ($#ARGV < 3) {
	print "Usage: $0 <input_file_name> <date_time_stamp> <START/END> <templatefile_name>\n\n";
	print "date_time_stamp format is YYYYMMDDhhmm\n";
	print "output is written to input_file_name.extract\n";
	exit;
}

$infile       = $ARGV[0];
$dtstamp      = $ARGV[1];
$op_flag      = $ARGV[2];
$templateFile = $ARGV[3];

%templateEntityHash = ();
$outfile            = $infile.'.extract';
@ipfound            = ();
$appendvar          = "";
$gNodeName           ="";

#creating object with Tool module
$tool = new Tool;

if ( -s $templateFile ) {
  read_template($templateFile);
} else {
  print "No user configured templates available\n\n";
  exit (1);
}

if ( $op_flag =~ /START/i ) {
	$start_range = $dtstamp;
	$end_range = $tool->create_reference($start_range,'add',30);
} elsif ( $op_flag =~ /END/i   ) {
	$end_range = $dtstamp;
	$start_range = $tool->create_reference($end_range,'sub',30);
}
 
#print Dumper [ %templateEntityHash ];

#open(IN, "<$infile")  || die ("Cannot open $infile.  :$!:\n");
open(OUT,">>$outfile") || die ("Cannot open $outfile. :$!:\n");
open(ERROR,">errfile") || die ("Cannot open errfile. :$!:\n");

$conf_not_found = 0;
while ( $line = <STDIN> ) {
	chomp $line;
	next if $line =~ /^$/;
	next if ( $conf_not_found == 1 && $line !~ /^ConfName/i && $line !~ /^NodeName/i && $line !~ /^Category/i  && $line !~ /^NodeAliasName/i );
	if ( $line =~ /^NodeName/i || $line =~ /^Category/i || $line =~ /^NodeAliasName/i ) {
		push @starting_section, $line;
		if ($line =~ /^NodeName/i)
		{
		  if ($line =~ /RNC/i) 
		  {
		    $gNodeName="RNC";
		  }
		elsif ($line =~ /DOM/i)
		   {
		     $gNodeName="DOM";
		   }
		}
		next;
	}
	
	if ($line =~ /^ConfName/ ) {
		my $templatename = (split(/=/,$line))[1];
		if ( !exists  $templateEntityHash{$templatename} ) {
			print ERROR "Error : $templatename not found \n";
			print ERROR "No user configured templates available\n\n";
			$conf_not_found = 1;
			@starting_section = ();
			next;
			#close (OUT);
		}
		$instance = $templateEntityHash{$templatename};
		if ($line =~ m/CPUUtilization/ && $gNodeName ne '' )
		{
		   $line="ConfName=CPUUtilization_By".$gNodeName; # Suffixes with _ByDOM or _ByRNC for CPUUti
		   $gNodeName='';
		} 
		if ($line =~ m/InterfaceUtilization/ && $gNodeName ne '' )
		{
		   $line="ConfName=InterfaceUtilizationByPort_By".$gNodeName;#Suffixes with _ByDOM or _ByRNC for Interface 
		   $gNodeName='';
		} 
		if ($line =~ m/QoSTxPriorityUtilization/ && $gNodeName ne '' )
		{
		   $line="ConfName=QoSTxPriorityUtilization_By".$gNodeName;#Suffixes with _ByDOM or _ByRNC for Interface 
		   $gNodeName='';
		} 
		if ($line =~ m/OvrldCtrl[_]?Card[_]?Resource[_]?Utilization/ && $gNodeName ne '' )
		{
		   $line="ConfName=OvrldCtrlCardResourceUtilization_By".$gNodeName;#Suffixes with _ByDOM or _ByRNC for Interface 
		   $gNodeName='';
		} 
		print OUT join("\n" , @starting_section,$line."\n" );
		@starting_section = ();
		$conf_not_found = 0;
	        $appendvar=""; # Reset appendVar since its a new confName 
			       # Fix for the extra var-nnn in header lines
		next;
	}
	
	($one, $two, $thr, @junk) = split(/\s+/,$line);

	if (uc($instance) eq 'A' && $one =~ /^\d\d\/\d\d\/\d\d\d\d$/) {
		($twx, $twy) = ($two =~ /(\d\d:\d\d):(\d\d)/);
		local ($year,$day,$month) = (split('\/',$one))[2,1,0];
		local ($hour,$min)        = (split(':',$two))[0,1];
		$data_dts=$one." ".$twx;
		$compare_with = "$year$month$day$hour$min";
		
		if ( $start_range <= $compare_with && $compare_with < $end_range ) {
			print OUT "$line\n";
		}
	}
	elsif (($two =~ /^\d\d\/\d\d\/\d\d\d\d$/) && (uc($instance) eq 'B' || uc($instance) eq 'C')) {
	    ($thx, $thy) = ($thr =~ /(\d\d:\d\d):(\d\d)/);
		local ($year,$day,$month) = (split('\/',$two))[2,1,0];
		local ($hour,$min)        = (split(':',$thr))[0,1];
		$data_dts=$two." ".$thx;
		$compare_with = "$year$month$day$hour$min";

		if ( $start_range <= $compare_with && $compare_with < $end_range ) {
			@dataLine = split(/\t+/, $line); #expecting tab delimited
			@dataLine1 = split(/\./, $dataLine[0]);

			if ( uc($instance) eq 'B' && @dataLine1 == 1 ) {
				$data = $line ."\t".$dataLine1[0];
			} elsif ( uc($instance) eq 'C' && @dataLine1 > 1 ) {
				$data = $line;
				foreach $name ( @ipfound ) {
					if ( $name == 1 ) {
						$temp1 = shift @dataLine1;
						$temp2 = shift @dataLine1;
						$temp3 = shift @dataLine1;
						$temp4 = shift @dataLine1;
						$tempn = $temp1.".".$temp2.".".$temp3.".".$temp4;
					}
					else {
						$tempn = shift @dataLine1;
					}
					$data=$data."\t".$tempn;
				}
			}
			print OUT "$data\n";
		}
	}
	else {
		process_on_data ( $one,$line );
	}
}

sub process_on_data {
	my $one  = shift;
	my $line = shift;
	@varname = split(/[()]/,$line);
	#return if $line =~ /^$/;

	if ($varname[0] =~ /^Instance Format:/ ) {
		@ipfound =();
		$line =~ s/ +//g;
		$varname[0] =~ s/Instance Format: +//g;
		#@Insvarname = split(/\./,$varname[0]);
		$i="$Instance_var[1]";
		foreach $lpeg ( split(/\./,$varname[0]) ) {
			if ( $lpeg =~ /IPADDRESS/i ) { push(@ipfound,1); }
			else                         { push(@ipfound,0); }
			$i++;
			$appendvar =$appendvar."Var-$i"."\t";
			print OUT "Var-$i = "."("."$lpeg".")\n";
		}
	}
	elsif ( ($varname[0] =~ /rncIPAddress/i || $varname[0] =~ /a12ServerIpAddressServer/i) )
	{
		@ipfound =();
		$i="$Instance_var[1]";
		$i++;
		($rncIP,$rest)= split(/\t/,$varname[0]);
		$appendvar =$appendvar."Var-$i"."\t";
                print OUT "Var-$i = "."("."$rncIP".")\n";
	        print OUT $line.$appendvar."\n";
		push(@ipfound,1);
	}
	elsif ( ($varname[0] =~ /Time/) ) { 
		print OUT "$line\n" if ( $instance =~  /A/i );

		if ( $instance =~ /b/i ) {
			my ($lengthdesc, $pegdesc, $flag) = $tool->pegformation($varname[0]);
			print OUT "Var-$lengthdesc = "."("."$pegdesc".")\n";
			print OUT "\n";
			print OUT $line."Var-".$lengthdesc."\n";
		} elsif ( $instance =~ /c/i ) {
			print OUT $line.$appendvar."\n" ;
		}
	} 
	else {
		print OUT "$line\n";
		@Instance_var=split(/-/,$one) if ($one =~ /Var-/);
	}

}

sub read_template {
	$file_to_read = shift;
	open(templateConfFile,$file_to_read);
	$minConfigField = 4;
	while ($line =<templateConfFile>)  {
		chomp($line);
		@lineWords = split('\|',$line);
		next if $line =~ /^#/;
	
		if (@lineWords >= $minConfigField) {
			($configTemplate,$with_instance) = (split (/\|/, $line))[0,3] ;
			$templateEntityHash{$configTemplate} =  $with_instance;
		}
		else {
			print "Missing fields at line $line in templateFile\n";
		}
	}
}

==> 7.1.16.7-TIV-PROSPECTDA-NORCDM-FP0000.tar: patches/7.1.16.7-TIV-PROSPECTDA-NORCDM-FP0000/extract_rmt.pl <==
#!/usr/bin/env perl

##########################################################################
#
# Licensed Materials - Property of IBM
# 5724-T10
#
# (C) Copyright IBM Corp. 2003,2008. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
##########################################################################

#! Anthony Jesu - 2006/05/02
#
# 1) This script parses the data from input file for the specified
#    time_stamp.for Example if the input time is 200507030200 then
#    and the arguement also passed 'start' then this program fetches
#    30 minutes interval of in forward manner. for example this will
#    fetch data from 2'O clock to 02:29 minutes of data. Instead of start
#    If you pass end, then this script fetches the information in reverse order.
#    In our case this will fetch information in the previous interval (i,e) from
#    01.30 to 01.59 of data.
# 2) Output filename is same as input filename with ".extract" appended.

use lib "$ENV{ FLEXDAHOME }/scripts/";
use Tool;

if ($#ARGV < 3) {
	print "Usage: $0 <input_file_name> <date_time_stamp> <START/END> <templatefile_name>\n\n";
	print "date_time_stamp format is YYYYMMDDhhmm\n";
	print "output is written to input_file_name.extract\n";
	exit;
}

$infile       = $ARGV[0];
$dtstamp      = $ARGV[1];
$op_flag      = $ARGV[2];
$templateFile = $ARGV[3];

%templateEntityHash = ();
$outfile            = $infile.'.extract';
@ipfound            = ();
$appendvar          = "";
$gNodeName           ="";

#creating object with Tool module
$tool = new Tool;

if ( -s $templateFile ) {
  read_template($templateFile);
} else {
  print "No user configured templates available\n\n";
  exit (1);
}

if ( $op_flag =~ /START/i ) {
	$start_range = $dtstamp;
	$end_range = $tool->create_reference($start_range,'add',30);
} elsif ( $op_flag =~ /END/i   ) {
	$end_range = $dtstamp;
	$start_range = $tool->create_reference($end_range,'sub',30);
}
 
#print Dumper [ %templateEntityHash ];

#open(IN, "<$infile")  || die ("Cannot open $infile.  :$!:\n");
open(OUT,">>$outfile") || die ("Cannot open $outfile. :$!:\n");
open(ERROR,">errfile") || die ("Cannot open errfile. :$!:\n");

$conf_not_found = 0;
while ( $line = <STDIN> ) {
	chomp $line;
	next if $line =~ /^$/;
	next if ( $conf_not_found == 1 && $line !~ /^ConfName/i && $line !~ /^NodeName/i && $line !~ /^Category/i  && $line !~ /^NodeAliasName/i );
	if ( $line =~ /^NodeName/i || $line =~ /^Category/i || $line =~ /^NodeAliasName/i ) {
		push @starting_section, $line;
		if ($line =~ /^NodeName/i)
		{
		  if ($line =~ /RNC/i) 
		  {
		    $gNodeName="RNC";
		  }
		elsif ($line =~ /DOM/i)
		   {
		     $gNodeName="DOM";
		   }
		}
		next;
	}
	
	if ($line =~ /^ConfName/ ) {
		my $templatename = (split(/=/,$line))[1];
		if ( !exists  $templateEntityHash{$templatename} ) {
			print ERROR "Error : $templatename not found \n";
			print ERROR "No user configured templates available\n\n";
			$conf_not_found = 1;
			@starting_section = ();
			next;
			#close (OUT);
		}
		$instance = $templateEntityHash{$templatename};
		if ($line =~ m/CPUUtilizationATCA/ && $gNodeName ne '' )
		{
		   $line="ConfName=CPUUtilizationATCA"; # No need to suffix for this 8.1 template.
		   $gNodeName='';
		} 
		elsif ($line =~ m/CPUUtilization/ && $gNodeName ne '' )
		{
		   $line="ConfName=CPUUtilization_By".$gNodeName; # Suffixes with _ByDOM or _ByRNC for CPUUti
		   $gNodeName='';
		} 
		if ($line =~ m/InterfaceUtilization/ && $gNodeName ne '' )
		{
		   $line="ConfName=InterfaceUtilizationByPort_By".$gNodeName;#Suffixes with _ByDOM or _ByRNC for Interface 
		   $gNodeName='';
		} 
		if ($line =~ m/QoSTxPriorityUtilization/ && $gNodeName ne '' )
		{
		   $line="ConfName=QoSTxPriorityUtilization_By".$gNodeName;#Suffixes with _ByDOM or _ByRNC for Interface 
		   $gNodeName='';
		} 
		if ($line =~ m/OvrldCtrl[_]?Card[_]?Resource[_]?Utilization/ && $gNodeName ne '' )
		{
		   $line="ConfName=OvrldCtrlCardResourceUtilization_By".$gNodeName;#Suffixes with _ByDOM or _ByRNC for Interface 
		   $gNodeName='';
		} 
		print OUT join("\n" , @starting_section,$line."\n" );
		@starting_section = ();
		$conf_not_found = 0;
	        $appendvar=""; # Reset appendVar since its a new confName 
			       # Fix for the extra var-nnn in header lines
		next;
	}
	
	($one, $two, $thr, @junk) = split(/\s+/,$line);

	if (uc($instance) eq 'A' && $one =~ /^\d\d\/\d\d\/\d\d\d\d$/) {
		($twx, $twy) = ($two =~ /(\d\d:\d\d):(\d\d)/);
		local ($year,$day,$month) = (split('\/',$one))[2,1,0];
		local ($hour,$min)        = (split(':',$two))[0,1];
		$data_dts=$one." ".$twx;
		$compare_with = "$year$month$day$hour$min";
		
		if ( $start_range <= $compare_with && $compare_with < $end_range ) {
			print OUT "$line\n";
		}
	}
	elsif (($two =~ /^\d\d\/\d\d\/\d\d\d\d$/) && (uc($instance) eq 'B' || uc($instance) eq 'C')) {
	    ($thx, $thy) = ($thr =~ /(\d\d:\d\d):(\d\d)/);
		local ($year,$day,$month) = (split('\/',$two))[2,1,0];
		local ($hour,$min)        = (split(':',$thr))[0,1];
		$data_dts=$two." ".$thx;
		$compare_with = "$year$month$day$hour$min";

		if ( $start_range <= $compare_with && $compare_with < $end_range ) {
			@dataLine = split(/\t+/, $line); #expecting tab delimited
			@dataLine1 = split(/\./, $dataLine[0]);

			if ( uc($instance) eq 'B' && @dataLine1 == 1 ) {
				$data = $line ."\t".$dataLine1[0];
			} elsif ( uc($instance) eq 'C' && @dataLine1 > 1 ) {
				$data = $line;
				foreach $name ( @ipfound ) {
					if ( $name == 1 ) {
						$temp1 = shift @dataLine1;
						$temp2 = shift @dataLine1;
						$temp3 = shift @dataLine1;
						$temp4 = shift @dataLine1;
						$tempn = $temp1.".".$temp2.".".$temp3.".".$temp4;
					}
					else {
						$tempn = shift @dataLine1;
					}
					$data=$data."\t".$tempn;
				}
			}
			print OUT "$data\n";
		}
	}
	else {
		process_on_data ( $one,$line );
	}
}

sub process_on_data {
	my $one  = shift;
	my $line = shift;
	@varname = split(/[()]/,$line);
	#return if $line =~ /^$/;

	if ($varname[0] =~ /^Instance Format:/ ) {
		@ipfound =();
		$line =~ s/ +//g;
		$varname[0] =~ s/Instance Format: +//g;
		#@Insvarname = split(/\./,$varname[0]);
		$i="$Instance_var[1]";
		foreach $lpeg ( split(/\./,$varname[0]) ) {
			if ( $lpeg =~ /IPADDRESS/i ) { push(@ipfound,1); }
			else                         { push(@ipfound,0); }
			$i++;
			$appendvar =$appendvar."Var-$i"."\t";
			print OUT "Var-$i = "."("."$lpeg".")\n";
		}
	}
	elsif ( ($varname[0] =~ /rncIPAddress/i || $varname[0] =~ /a12ServerIpAddressServer/i) )
	{
		@ipfound =();
		$i="$Instance_var[1]";
		$i++;
		($rncIP,$rest)= split(/\t/,$varname[0]);
		$appendvar =$appendvar."Var-$i"."\t";
                print OUT "Var-$i = "."("."$rncIP".")\n";
	        print OUT $line.$appendvar."\n";
		push(@ipfound,1);
	}
	elsif ( ($varname[0] =~ /Time/) ) { 
		print OUT "$line\n" if ( $instance =~  /A/i );

		if ( $instance =~ /b/i ) {
			my ($lengthdesc, $pegdesc, $flag) = $tool->pegformation($varname[0]);
			print OUT "Var-$lengthdesc = "."("."$pegdesc".")\n";
			print OUT "\n";
			print OUT $line."Var-".$lengthdesc."\n";
		} elsif ( $instance =~ /c/i ) {
			print OUT $line.$appendvar."\n" ;
		}
	} 
	else {
		print OUT "$line\n";
		@Instance_var=split(/-/,$one) if ($one =~ /Var-/);
	}

}

sub read_template {
	$file_to_read = shift;
	open(templateConfFile,$file_to_read);
	$minConfigField = 4;
	while ($line =<templateConfFile>)  {
		chomp($line);
		@lineWords = split('\|',$line);
		next if $line =~ /^#/;
	
		if (@lineWords >= $minConfigField) {
			($configTemplate,$with_instance) = (split (/\|/, $line))[0,3] ;
			$templateEntityHash{$configTemplate} =  $with_instance;
		}
		else {
			print "Missing fields at line $line in templateFile\n";
		}
	}
}
